# Kernel Performance Tweaks Module

高级内核参数调优模块，旨在通过优化各种内核参数来提升系统性能和电池续航。

## 功能特性

### CPU调度器优化
- 调整调度延迟和粒度参数
- 优化CPU频率缩放策略
- 智能选择最佳调速器（interactive/ondemand）

### 内存管理优化
- 优化虚拟内存参数（swap、缓存压力等）
- 调整脏页管理策略
- 配置透明大页面支持

### I/O性能优化
- 根据存储类型自动选择最佳I/O调度器
- 优化队列深度和预读参数
- 区分HDD和SSD的不同优化策略

### 网络性能优化
- 调整TCP缓冲区大小
- 启用BBR拥塞控制算法（如支持）
- 优化网络窗口缩放和时间戳

### 电源管理优化
- 启用深度CPU空闲状态
- 优化热管理设置
- 平衡性能与功耗

### GPU优化
- 支持Adreno GPU优化
- 支持Mali GPU优化
- 智能GPU调速策略

### 性能监控
- 内置性能监控脚本
- 定期记录系统状态
- 便于性能分析和调试

## 安装说明

1. 在KernelSU管理器中安装此模块
2. 重启设备以应用所有优化
3. 查看日志文件确认优化状态

## 配置选项

### 内核模块配置
编辑 `kernel-modules.conf` 文件可以指定需要加载的内核模块：

```bash
# 网络相关模块
tun
tap

# 文件系统模块
fuse
```

### 自定义参数
如需自定义特定参数，可以编辑 `service.sh` 文件中的相关函数。

## 日志文件

模块运行日志保存在：
- `logs/kernel-tweaks.log` - 主要日志文件
- `/data/local/tmp/performance-monitor.log` - 性能监控日志

## 注意事项

⚠️ **重要提醒**：
- 此模块会修改系统核心参数，请谨慎使用
- 建议在测试环境中先行验证
- 某些优化可能不适用于所有设备
- 如遇到问题，可以禁用模块并重启

## 兼容性

- ✅ 支持Android 8.0+
- ✅ 支持ARM64架构
- ✅ 支持大多数主流SoC
- ✅ 兼容KernelSU和Magisk

## 性能效果

预期效果：
- 🚀 提升应用启动速度 10-20%
- 🔋 改善电池续航 5-15%
- 📱 减少系统卡顿现象
- 🌐 提升网络传输效率

## 故障排除

### 常见问题

**Q: 应用优化后系统变慢了？**
A: 部分设备可能需要特定调整，请检查日志文件并根据设备特性修改参数。

**Q: 某些参数无法设置？**
A: 这是正常现象，模块会自动跳过不支持的参数，不影响其他优化。

**Q: 如何查看优化效果？**
A: 可以使用性能监控日志或第三方性能测试应用进行对比。

### 回滚方法

如需回滚优化：
1. 在KernelSU管理器中禁用模块
2. 重启设备
3. 系统参数将恢复默认值

## 更新日志

### v1.2 (2024-12-01)
- 新增GPU优化支持
- 改进I/O调度器选择逻辑
- 添加性能监控功能
- 优化错误处理机制

### v1.1
- 添加网络优化功能
- 改进电源管理
- 增强兼容性检查

### v1.0
- 初始版本发布
- 基础CPU和内存优化
- I/O调度器优化

## 技术支持

如有问题或建议，请：
1. 查看日志文件获取详细信息
2. 在KernelSU社区提交反馈
3. 参考官方文档进行排查

## 许可证

本模块基于MIT许可证发布，可自由使用和修改。
